@@ -42,9 +42,9 @@ residuals.KFS <-  function(object,
 
   series <- switch(type,
     recursive = {
-      if(any(object$model$distribution !=  "gaussian") && is.null(object[["m", exact = TRUE]]))
+      if(any(object$model$distribution !=  "gaussian") && !("m" %in% names(object)))
         stop("KFS object does not contain filtered means. ")
-      if (all(object$model$distribution ==  "gaussian") && is.null(object[["v", exact = TRUE]]))
+      if (all(object$model$distribution ==  "gaussian") && !("v" %in% names(object)))
         stop("KFS object does not contain prediction errors v. ")
       if(all(object$model$distribution ==  "gaussian")){
         series <- object$v
@@ -63,7 +63,7 @@ residuals.KFS <-  function(object,
       series - fitted(object)
     },
     state = {
-      if (is.null(object$etahat)) {
+      if (!("etahat" %in% names(object))) {
         stop("KFS object needs to contain smoothed estimates of state disturbances eta.")
       } else {
         object$etahat
